import { CollectionConfig } from 'payload/types';

const Dispatches: CollectionConfig = {
  slug: 'dispatches',
  admin: {
    useAsTitle: 'code',
  },
  access: {
    read: () => true,
  },
  fields: [
    {
      name: 'code',
      type: 'text', 
      required: true,
      maxLength: 20,
      unique: true,
      label: "Code, a unique name for the dispatch"
    },
    {
      name: 'products', 
      type: 'relationship', 
      relationTo: 'products', 
      hasMany: true,
      required: true,
    },
    {
      name: 'courier', 
      type: 'relationship', 
      relationTo: 'couriers', 
      hasMany: false,
      required: false
    },
    {
      name: 'maker', 
      type: 'relationship', 
      relationTo: 'makers', 
      hasMany: false,
      required: true
    },
    {
      name: 'retailer', 
      type: 'relationship', 
      relationTo: 'retailers', 
      hasMany: false,
      required: true
    },
    {
      name: 'status',
      type: 'select',
      hasMany: false,
      required: true,
      options: [
        {
          label: 'Requested',
          value: 'requested',
        },
        {
          label: 'Accepted',
          value: 'accepted',
        },
        {
          label: 'Archived',
          value: 'archived',
        },
      ],
    }
  ],
};

export default Dispatches;

// type Dispatch = {
//   id: string;
//   dispatchesCode: string; //Human readable id
//   createdAt: string;
//   updatedAt: string;

//   maker: Maker;
//   retailer: Retailer;
//   products: Product[];

//   courier: User;
  
//   timeSensitive: boolean;
//   status: DispatchStatus[];

//   departureDate: string;
//   arrivalDate: string;
//   weightAllowance: number;
// }
